@@ -1,5 +1,4 @@
 import os
-import socket
 
 from ansys.dpf.core._version import __version__
 
@@ -82,6 +81,7 @@ from ansys.dpf.core import check_version
 from ansys.dpf.core import path_utilities
 from ansys.dpf.core import settings
 from ansys.dpf.core.server_factory import ServerConfig, AvailableServerConfigs
+from ansys.dpf.core.server_context import set_default_server_context, AvailableServerContexts
 
 # for matplotlib
 # solves "QApplication: invalid style override passed, ignoring it."
