@@ -7,8 +7,8 @@ Contains classes associated with the DPF FieldsContainer.
 """
 from ansys import dpf
 from ansys.dpf.core.collection import Collection
-from ansys.dpf.core.common import types
 from ansys.dpf.core import errors as dpf_errors
+from ansys.dpf.core import field
 
 
 class FieldsContainer(Collection):
@@ -25,7 +25,8 @@ class FieldsContainer(Collection):
 
     Parameters
     ----------
-    fields_container : ansys.grpc.dpf.collection_pb2.Collection or FieldsContainer, optional
+    fields_container : ansys.grpc.dpf.collection_pb2.Collection, ctypes.c_void_p,
+    FieldsContainer, optional
         Fields container created from either a collection message or by copying an existing
         fields container. The default is "None``.
     server : ansys.dpf.core.server, optional
@@ -63,21 +64,22 @@ class FieldsContainer(Collection):
     """
 
     def __init__(self, fields_container=None, server=None):
-        """Initialize the scoping with either an optional scoping message
-        or by connecting to a stub.
-        """
-        if server is None:
-            server = dpf.core._global_server()
-
-        self._server = server
-        self._stub = self._connect()
+        super().__init__(
+            collection=fields_container, server=server
+        )
+        if self._internal_obj is None:
+            if self._server.has_client():
+                self._internal_obj = self._api.collection_of_field_new_on_client(
+                    self._server.client
+                )
+            else:
+                self._internal_obj = self._api.collection_of_field_new()
 
         self._component_index = None  # component index
         self._component_info = None  # for norm/max/min
 
-        Collection.__init__(
-            self, types.field, collection=fields_container, server=self._server
-        )
+    def create_subtype(self, obj_by_copy):
+        return field.Field(field=obj_by_copy, server=self._server)
 
     def get_fields_by_time_complex_ids(self, timeid=None, complexid=None):
         """Retrieve fields at a requested time ID or complex ID.
@@ -338,12 +340,13 @@ class FieldsContainer(Collection):
     def add_field_by_time_id(self, field, timeid=1):
         """Add or update a field at a requested time ID.
 
-         Parameters
-         ----------
-         field : Field
-             DPF field to add or update.
+        Parameters
+        ----------
+        field : Field
+            DPF field to add or update.
         timeid: int, optional
-             Time ID for the requested time set. The default is ``1``.
+            Time ID for the requested time set. The default is ``1``.
+
         """
         labels = self.labels
         if not self.has_label("time") and (
@@ -486,6 +489,111 @@ class FieldsContainer(Collection):
         """
         return self.get_label_scoping("time")
 
+    def animate(self, save_as=None, deform_by=None, scale_factor=1.0, **kwargs):
+        """Creates an animation based on the Fields contained in the FieldsContainer.
+
+        This method creates a movie or a gif based on the time ids of a FieldsContainer.
+        For kwargs see pyvista.Plotter.open_movie/add_text/show.
+
+        Parameters
+        ----------
+        save_as : Path of file to save the animation to. Defaults to None. Can be of any format
+            supported by pyvista.Plotter.write_frame (.gif, .mp4, ...).
+        deform_by : FieldsContainer, Result, Operator, optional
+            Used to deform the plotted mesh. Must return a FieldsContainer of the same length as
+            self, containing 3D vector Fields of distances.
+            Defaults to None, which takes self if possible. Set as False to force static animation.
+        scale_factor : float, list, optional
+            Scale factor to apply when warping the mesh. Defaults to 1.0. Can be a list to make
+            scaling frequency-dependent.
+        """
+        from ansys.dpf.core.animator import Animator
+
+        # Create a workflow defining the result to render at each step of the animation
+        wf = dpf.core.Workflow()
+        # First define the workflow index input
+        forward_index = dpf.core.operators.utility.forward()
+        wf.set_input_name("loop_over", forward_index.inputs.any)
+        # Define the field extraction using the fields_container and indices
+        extract_field_op = dpf.core.operators.utility.extract_field(self)
+        to_render = extract_field_op.outputs.field
+        n_components = self[0].component_count
+        if n_components > 1:
+            norm_op = dpf.core.operators.math.norm(extract_field_op.outputs.field)
+            to_render = norm_op.outputs.field
+
+        loop_over = self.get_time_scoping()
+        frequencies = self.time_freq_support.time_frequencies
+        if frequencies is None:
+            raise ValueError("The fields_container has no time_frequencies.")
+
+        loop_over = self.get_time_scoping()
+        frequencies = self.time_freq_support.time_frequencies
+        if frequencies is None:
+            raise ValueError("The fields_container has no time_frequencies.")
+
+        # TODO /!\ We should be using a mechanical::time_selector, however it is not wrapped.
+
+        wf.set_input_name("indices", extract_field_op.inputs.indices)  # Have to do it this way
+        wf.connect("indices", forward_index)  # Otherwise not accepted
+        # Add the operators to the workflow
+        wf.add_operators([extract_field_op, forward_index])
+
+        deform = True
+        # Define whether to deform and what with
+        if deform_by is not False:
+            if deform_by is None or isinstance(deform_by, bool):
+                # By default, set deform_by as self if nodal 3D vector field
+                if self[0].location == dpf.core.common.locations.nodal and \
+                        n_components == 3:
+                    deform_by = self
+                else:
+                    deform = False
+            if deform_by and not isinstance(deform_by, dpf.core.FieldsContainer):
+                deform_by = deform_by.eval()
+                if len(deform_by) != len(self):
+                    raise ValueError("'deform_by' argument must result in a FieldsContainer "
+                                     "of same length as the animated one "
+                                     f"(len(deform_by.eval())={len(deform_by)} "
+                                     f"!= len(self)={len(self)}).")
+        else:
+            deform = False
+
+        if deform:
+            scale_factor_fc = dpf.core.animator.scale_factor_to_fc(scale_factor, deform_by)
+            scale_factor_invert = dpf.core.operators.math.invert_fc(scale_factor_fc)
+            # Extraction of the field of interest based on index
+            # time_selector = dpf.core.Operator("mechanical::time_selector")
+            extract_field_op_2 = dpf.core.operators.utility.extract_field(deform_by)
+            wf.set_input_name("indices", extract_field_op_2.inputs.indices)
+            wf.connect("indices", forward_index)  # Otherwise not accepted
+            # Scaling of the field based on scale_factor and index
+            extract_scale_factor_op = dpf.core.operators.utility.extract_field(scale_factor_invert)
+            wf.set_input_name("indices", extract_scale_factor_op.inputs.indices)
+            wf.connect("indices", forward_index)  # Otherwise not accepted
+
+            divide_op = dpf.core.operators.math.component_wise_divide(
+                extract_field_op_2.outputs.field, extract_scale_factor_op.outputs.field)
+            wf.set_output_name("deform_by", divide_op.outputs.field)
+        else:
+            scale_factor = None
+        wf.set_output_name("to_render", to_render)
+        wf.progress_bar = False
+
+        loop_over_field = dpf.core.fields_factory.field_from_array(
+            frequencies.data[loop_over.ids-1])
+        loop_over_field.scoping.ids = loop_over.ids
+        loop_over_field.unit = frequencies.unit
+
+        # Initiate the Animator
+        anim = Animator(workflow=wf, **kwargs)
+
+        kwargs.setdefault("freq_kwargs", {"font_size": 12, "fmt": ".3e"})
+
+        return anim.animate(loop_over=loop_over_field,
+                            save_as=save_as, scale_factor=scale_factor,
+                            **kwargs)
+
     def __add__(self, fields_b):
         """Add two fields or two fields containers.
 
@@ -524,7 +632,7 @@ class FieldsContainer(Collection):
 
     def __pow__(self, value):
         if value != 2:
-            raise ValueError('DPF only the value is "2" suppported')
+            raise ValueError('DPF only the value is "2" supported')
         from ansys.dpf.core import dpf_operator
         from ansys.dpf.core import operators
 
