@@ -460,7 +460,7 @@ class MeshedRegion:
             coordinates_field = coordinates
             coordinates = coordinates.data
         etypes = self.elements.element_types_field.data
-        conn = self.elements.connectivities_field.data
+        conn = self.elements.connectivities_field
         try:
             from ansys.dpf.core.vtk_helper import dpf_mesh_to_vtk
         except ModuleNotFoundError:
@@ -468,8 +468,7 @@ class MeshedRegion:
                 "To use plotting capabilities, please install pyvista "
                 "with :\n pip install pyvista>=0.24.0"
             )
-
-        grid = dpf_mesh_to_vtk(coordinates, etypes, conn, as_linear)
+        grid = dpf_mesh_to_vtk(coordinates, etypes, conn, as_linear, self)
 
         # consider adding this when scoping request is faster
         if include_ids:
