@@ -2,12 +2,15 @@
 import platform
 import glob
 import os
+
+import packaging.version
+import pkg_resources
+import importlib
 from pkgutil import iter_modules
 from ansys.dpf.gate._version import (
     __ansys_version__
 )
 
-
 DEFAULT_FILE_CHUNK_SIZE = 524288
 DYNAMIC_RESULTS = True
 RETURN_ARRAYS = True
@@ -97,6 +100,42 @@ def get_ansys_path(ansys_path=None):
     return ansys_path
 
 
+def _pythonize_awp_version(version):
+    if len(version) != 3:
+        return version
+    return "20" + version[0:2] + "." + version[2]
+
+
+def _find_latest_ansys_versions():
+    awp_versions = [key[-3:] for key in os.environ.keys() if "AWP_ROOT" in key]
+    installed_packages_list = {}
+
+    for awp_version in awp_versions:
+        if not awp_version.isnumeric():
+            continue
+        ansys_path = os.environ.get("AWP_ROOT" + awp_version)
+        if ansys_path:
+            installed_packages_list[
+                packaging.version.parse(_pythonize_awp_version(awp_version))
+            ] = ansys_path
+
+    installed_packages = pkg_resources.working_set
+    for i in installed_packages:
+        if "ansys-dpf-server" in i.key:
+            file_name = pkg_resources.to_filename(i.project_name.replace("ansys-dpf-", ""))
+            try:
+                module = importlib.import_module("ansys.dpf."+file_name)
+                installed_packages_list[
+                    packaging.version.parse(module.__version__)
+                ] = module.__path__[0]
+            except ModuleNotFoundError:
+                pass
+            except AttributeError:
+                pass
+    if len(installed_packages_list) > 0:
+        return installed_packages_list[sorted(installed_packages_list)[-1]]
+
+
 def find_ansys():
     """Search for a standard ANSYS environment variable (AWP_ROOTXXX) or a standard installation
     location to find the path to the latest Ansys installation.
@@ -118,13 +157,9 @@ def find_ansys():
     >>> path = find_ansys()
 
     """
-    versions = [key[-3:] for key in os.environ.keys() if "AWP_ROOT" in key]
-    for version in sorted(versions, reverse=True):
-        if not version.isnumeric():
-            continue
-        ansys_path = os.environ.get("AWP_ROOT" + version)
-        if ansys_path:
-            return ansys_path
+    latest_install = _find_latest_ansys_versions()
+    if latest_install:
+        return latest_install
 
     base_path = None
     if os.name == "nt":
