@@ -1,3 +1,4 @@
+from .field_signed_high_pass import field_signed_high_pass 
 from .field_band_pass_fc import field_band_pass_fc 
 from .scoping_low_pass import scoping_low_pass 
 from .field_high_pass import field_high_pass 
@@ -7,3 +8,4 @@ from .field_low_pass import field_low_pass
 from .field_low_pass_fc import field_low_pass_fc 
 from .field_band_pass import field_band_pass 
 from .scoping_band_pass import scoping_band_pass 
+from .signed_scoping_high_pass import signed_scoping_high_pass 
