@@ -7,7 +7,6 @@ This module contains the Results and Result classes that are created by the mode
 to easily access results in result files."""
 import functools
 
-
 from ansys.dpf.core import Operator
 from ansys.dpf.core import errors
 from ansys.dpf.core.scoping import Scoping
@@ -35,7 +34,7 @@ class Results:
 
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.msup_transient)
+        >>> model = dpf.Model(examples.find_msup_transient())
         >>> disp = model.results.displacement.on_last_time_freq.on_named_selection("_CONSTRAINEDNODES")
         >>> last_time_disp = disp.eval()
 
@@ -50,7 +49,7 @@ class Results:
 
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.msup_transient)
+        >>> model = dpf.Model(examples.find_msup_transient())
         >>> stress = model.results.stress.on_last_time_freq.on_named_selection('_CONSTRAINEDNODES')
         >>> last_time_stress = stress.eval()
 
@@ -60,13 +59,10 @@ class Results:
 
         Examples
         --------
-        Create a stress result from the model and choose its time and mesh scopings.
-
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.electric_therm)
+        >>> model = dpf.Model(examples.find_electric_therm())
         >>> v = model.results.electric_potential
-        >>> rf = model.results.reaction_force
         >>> dissip = model.results.thermal_dissipation_energy
 
     Examples
@@ -75,7 +71,7 @@ class Results:
 
     >>> from ansys.dpf import core as dpf
     >>> from ansys.dpf.core import examples
-    >>> model = dpf.Model(examples.simple_bar)
+    >>> model = dpf.Model(examples.find_simple_bar())
     >>> results = model.results # printable object
 
     Access the displacement at all times.
@@ -88,17 +84,21 @@ class Results:
 
     """  # noqa: E501
 
-    def __init__(self, model):
-        self.__class__ = type(Results.__name__ + str(id(self)), (Results,), {})
-
-        self._result_info = model.metadata.result_info
-        self._model = model
-        self._connect_operators()
+    def __init__(
+            self, connector, result_info, mesh_by_default=True, server=None, generate_ops=True
+    ):
+        self._connector = connector
+        self._mesh_by_default = mesh_by_default
+        self._server = server
+        if generate_ops:
+            self.__class__ = type(Results.__name__ + str(id(self)), (Results,), {})
+            self._connect_operators(result_info)
+        self._str = str(result_info)
 
     def __result__(self, result_type, *args):
-        return Result(self._model, result_type)
+        return Result(self._connector, self._mesh_by_default, result_type, self._server)
 
-    def _connect_operators(self):
+    def _connect_operators(self, result_info):
         """Dynamically add operators for results.
 
         The new operator's subresults are connected to the model's
@@ -117,14 +117,14 @@ class Results:
         >>> disp_z = model.results.displacement().Z()
 
         """
-        if self._result_info is None:
+        if result_info is None:
             return
         # dynamically add function based on input type
         self._op_map_rev = {}
-        for result_type in self._result_info:
+        for result_type in result_info:
             try:
                 doc = Operator(
-                    result_type.operator_name, server=self._model._server
+                    result_type.operator_name, server=self._server
                 ).__str__()
                 bound_method = self.__result__
                 method2 = functools.partial(bound_method, result_type)
@@ -138,7 +138,7 @@ class Results:
                 raise e
 
     def __str__(self):
-        return str(self._result_info)
+        return self._str
 
     def __iter__(self):
         for key in self._op_map_rev:
@@ -167,7 +167,7 @@ class Result:
 
     >>> from ansys.dpf import core as dpf
     >>> from ansys.dpf.core import examples
-    >>> model = dpf.Model(examples.msup_transient)
+    >>> model = dpf.Model(examples.find_msup_transient())
     >>> disp = model.results.displacement.on_last_time_freq.on_named_selection('_CONSTRAINEDNODES')
     >>> last_time_disp = disp.eval()
 
@@ -182,18 +182,20 @@ class Result:
     Create a strain result from the model on all time sets and recover the
     operator to connect it to other operators.
 
-    >>> model = dpf.Model(examples.msup_transient)
+    >>> model = dpf.Model(examples.find_msup_transient())
     >>> strain = model.results.elastic_strain.on_all_time_freqs()
     >>> eqv = dpf.operators.invariant.von_mises_eqv_fc(strain)
     >>> strain_eqv = eqv.outputs.fields_container()
 
     """
 
-    def __init__(self, model, result_info):
-        self._model = model
+    def __init__(self, connector, mesh_by_default, result_info, server):
+        self._server = server
+        self._connector = connector
         self._time_scoping = None
         self._mesh_scoping = None
         self._location = None
+        self._mesh_by_default = mesh_by_default
         if isinstance(result_info, str):
             from ansys.dpf.core.available_result import available_result_from_name
             self._result_info = available_result_from_name(result_info)
@@ -206,21 +208,21 @@ class Result:
             # create the operator to read its documentation
             # if the operator doesn't exist, the method will not be added
             doc = Operator(
-                self._result_info.operator_name, server=self._model._server
+                self._result_info.operator_name, server=self._server
             ).__str__()
             self.__doc__ = doc
             if hasattr(operators, "result") and hasattr(
-                operators.result, self._result_info.name
+                    operators.result, self._result_info.name
             ):
                 self._operator = getattr(operators.result, self._result_info.name)(
-                    server=self._model._server
+                    server=self._server
                 )
             else:
                 self._operator = Operator(
-                    self._result_info.operator_name, server=self._model._server
+                    self._result_info.operator_name, server=self._server
                 )
+            self._connector.__connect_op__(self._operator, self._mesh_by_default)
             self._operator._add_sub_res_operators(self._result_info.sub_results)
-            self._model.__connect_op__(self._operator)
         except errors.DPFServerException:
             pass
         except Exception as e:
@@ -258,21 +260,21 @@ class Result:
         --------
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.msup_transient)
+        >>> model = dpf.Model(examples.find_msup_transient())
         >>> disp = model.results.displacement
         >>> fc = disp.on_all_time_freqs.eval()
 
         """
         fc = self.__call__().outputs.fields_container()
         if self._specific_fc_type == "shape":
-            fc = ElShapeFieldsContainer(fields_container=fc, server=fc._server)
+            fc = ElShapeFieldsContainer(fields_container=fc._get_ownership(), server=fc._server)
         elif self._specific_fc_type == "body":
-            fc = BodyFieldsContainer(fields_container=fc, server=fc._server)
+            fc = BodyFieldsContainer(fields_container=fc._get_ownership(), server=fc._server)
         return fc
 
     @property
     def on_all_time_freqs(self):
-        """Sets the time scoping to all the time frequencies available in the time frequency support.
+        """Sets the time scoping to all the time frequencies of the time frequency support.
 
         Returns
         -------
@@ -282,20 +284,21 @@ class Result:
         --------
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.msup_transient)
+        >>> model = dpf.Model(examples.find_msup_transient())
         >>> disp = model.results.displacement
         >>> disp.on_all_time_freqs.eval().get_label_scoping("time").ids
-        [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20]
+        <BLANKLINE>
+        ...1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20]...
 
         """
         self._time_scoping = list(
-            range(1, len(self._model.metadata.time_freq_support.time_frequencies) + 1)
+            range(1, len(self._connector.time_freq_support.time_frequencies) + 1)
         )
         return self
 
     @property
     def on_first_time_freq(self):
-        """Sets the time scoping to the first time frequency available in the time frequency support.
+        """Sets the time scoping to the first time frequency of the time frequency support.
 
         Returns
         -------
@@ -305,10 +308,11 @@ class Result:
         --------
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.msup_transient)
+        >>> model = dpf.Model(examples.find_msup_transient())
         >>> disp = model.results.displacement
         >>> disp.on_first_time_freq.eval().get_label_scoping("time").ids
-        [1]
+        <BLANKLINE>
+        ...[1]...
 
         """
         self._time_scoping = 1
@@ -326,14 +330,15 @@ class Result:
         --------
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.msup_transient)
+        >>> model = dpf.Model(examples.find_msup_transient())
         >>> disp = model.results.displacement
         >>> disp.on_last_time_freq.eval().get_label_scoping("time").ids
-        [20]
+        <BLANKLINE>
+        ...[20]...
 
         """
         self._time_scoping = len(
-            self._model.metadata.time_freq_support.time_frequencies
+            self._connector.time_freq_support.time_frequencies
         )
         return self
 
@@ -355,7 +360,7 @@ class Result:
 
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.msup_transient)
+        >>> model = dpf.Model(examples.find_msup_transient())
         >>> stress = model.results.stress
         >>> fc = stress.on_time_scoping([1,2,3,19]).eval()
         >>> len(fc)
@@ -368,7 +373,7 @@ class Result:
         >>> len(fc)
         2
         >>> fc.time_freq_support.time_frequencies.data
-        array([0.115, 0.125])
+        DPFArray([0.115, 0.125]...
 
         """
         self._time_scoping = time_scoping
@@ -392,7 +397,7 @@ class Result:
 
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.msup_transient)
+        >>> model = dpf.Model(examples.find_msup_transient())
         >>> stress = model.results.stress
         >>> fc = stress.on_first_time_freq.on_named_selection('_CONSTRAINEDNODES').eval()
         >>> len(fc[0].scoping)
@@ -400,7 +405,7 @@ class Result:
 
         """
 
-        self._mesh_scoping = self._model.metadata.named_selection(named_selection)
+        self._mesh_scoping = self._connector.named_selection(named_selection)
         return self
 
     @property
@@ -421,7 +426,8 @@ class Result:
         >>> len(fc_disp)
         11
         >>> fc_disp.get_mat_scoping().ids
-        [1, 5, 6, 10, 2, 7, 8, 13, 4, 12, 15]
+        <BLANKLINE>
+        ...1, 5, 6, 10, 2, 7, 8, 13, 4, 12, 15]...
         >>> disp_mat_10 = fc_disp.get_field_by_mat_id(10)
 
         """
@@ -460,7 +466,7 @@ class Result:
         from ansys.dpf.core import operators
 
         if hasattr(operators, "scoping") and hasattr(
-            operators.scoping, "split_on_property_type"
+                operators.scoping, "split_on_property_type"
         ):
             self._mesh_scoping = operators.scoping.split_on_property_type()
         else:
@@ -469,7 +475,7 @@ class Result:
         self._mesh_scoping.inputs.requested_location(
             self._result_info.native_scoping_location
         )
-        self._mesh_scoping.inputs.mesh(self._model.metadata.mesh_provider)
+        self._mesh_scoping.inputs.mesh(self._connector.mesh_provider)
         self._mesh_scoping.inputs.label1(prop)
         if previous_mesh_scoping:
             try:
@@ -495,7 +501,7 @@ class Result:
 
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.complex_rst)
+        >>> model = dpf.Model(examples.find_complex_rst())
         >>> disp = model.results.displacement
         >>> fc = disp.on_mesh_scoping([1,2,3]).eval()
         >>> len(fc[0].scoping)
@@ -516,7 +522,7 @@ class Result:
             mesh_scoping = Scoping(
                 ids=mesh_scoping,
                 location=self._result_info.native_scoping_location,
-                server=self._model._server,
+                server=self._server,
             )
 
         self._mesh_scoping = mesh_scoping
@@ -541,7 +547,7 @@ class Result:
 
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.complex_rst)
+        >>> model = dpf.Model(examples.find_complex_rst())
         >>> stress = model.results.stress
         >>> fc = stress.eval()
         >>> fc[0].location
@@ -566,15 +572,15 @@ class CommonResults(Results):
     Used to allow type hints and auto completion for the method:'results'
     of the class:'Results'.
     """
-    def __init__(self, model):
-        self._model = model
+
+    def __init__(self, connector, mesh_by_default, result_info, server):
+        super().__init__(connector, mesh_by_default, result_info, server, False)
         self._op_map_rev = dict(displacement="displacement",
                                 stress="stress",
                                 elastic_strain="elastic_strain",
                                 structural_temperature="structural_temperature",
                                 temperature="temperature",
                                 electric_potential="electric_potential")
-        self._result_info = model.metadata.result_info
 
     @property
     def displacement(self):
@@ -594,7 +600,7 @@ class CommonResults(Results):
 
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.msup_transient)
+        >>> model = dpf.Model(examples.find_msup_transient())
         >>> disp = model.results.displacement
         >>> disp = disp.on_last_time_freq.on_named_selection("_CONSTRAINEDNODES")
         >>> last_time_disp = disp.eval()
@@ -619,7 +625,7 @@ class CommonResults(Results):
 
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.msup_transient)
+        >>> model = dpf.Model(examples.find_msup_transient())
         >>> strain = model.results.elastic_strain
         >>> strain = strain.on_last_time_freq.on_named_selection("_CONSTRAINEDNODES")
         >>> last_time_disp = strain.eval()
@@ -644,7 +650,7 @@ class CommonResults(Results):
 
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.msup_transient)
+        >>> model = dpf.Model(examples.find_msup_transient())
         >>> stress = model.results.stress
         >>> stress = stress.on_last_time_freq.on_named_selection("_CONSTRAINEDNODES")
         >>> last_time_disp = stress.eval()
@@ -670,7 +676,7 @@ class CommonResults(Results):
 
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.complex_rst)
+        >>> model = dpf.Model(examples.find_complex_rst())
         >>> structural_temperature = model.results.structural_temperature
         >>> structural_temperature = structural_temperature.on_last_time_freq()
         >>> last_time_disp = structural_temperature.eval()
@@ -696,7 +702,7 @@ class CommonResults(Results):
 
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.steady_therm)
+        >>> model = dpf.Model(examples.find_steady_therm())
         >>> temperature = model.results.temperature.on_last_time_freq()
         >>> last_time_disp = temperature.eval()
         """
@@ -721,7 +727,7 @@ class CommonResults(Results):
 
         >>> from ansys.dpf import core as dpf
         >>> from ansys.dpf.core import examples
-        >>> model = dpf.Model(examples.electric_therm)
+        >>> model = dpf.Model(examples.find_electric_therm())
         >>> electric_potential = model.results.electric_potential.on_first_time_freq()
         >>> last_time_disp = electric_potential.eval()
         """
