@@ -12,8 +12,8 @@ import subprocess
 import time
 import warnings
 import traceback
+from threading import Thread, Lock
 from abc import ABC
-from threading import Thread
 
 import psutil
 
@@ -25,6 +25,7 @@ from ansys.dpf.core._version import (
     server_to_ansys_version
 )
 from ansys.dpf.core.misc import __ansys_version__
+from ansys.dpf.core import server_context
 from ansys.dpf.gate import load_api, data_processing_grpcapi
 
 import logging
@@ -94,7 +95,7 @@ def _verify_ansys_path_is_valid(ansys_path, executable, path_in_install=None):
 
 
 def _run_launch_server_process(ip, port, ansys_path=None,
-                               docker_config=server_factory.DockerConfig()):
+                               docker_config=server_factory.RunningDockerConfig()):
     bShell = False
     if docker_config.use_docker:
         docker_server_port = int(os.environ.get("DOCKER_SERVER_PORT", port))
@@ -128,17 +129,19 @@ def _wait_and_check_server_connection(
         process, port, timeout, lines, current_errors, stderr=None, stdout=None):
     if not stderr:
         def read_stderr():
-            for line in io.TextIOWrapper(process.stderr, encoding="utf-8"):
-                LOG.error(line)
-                current_errors.append(line)
+            with io.TextIOWrapper(process.stderr, encoding="utf-8") as log_err:
+                for line in log_err:
+                    LOG.error(line)
+                    current_errors.append(line)
 
         stderr = read_stderr
         # check to see if the service started
     if not stdout:
         def read_stdout():
-            for line in io.TextIOWrapper(process.stdout, encoding="utf-8"):
-                LOG.debug(line)
-                lines.append(line)
+            with io.TextIOWrapper(process.stdout, encoding="utf-8") as log_out:
+                for line in log_out:
+                    LOG.debug(line)
+                    lines.append(line)
 
         stdout = read_stdout
 
@@ -200,12 +203,17 @@ def launch_dpf(ansys_path, ip=LOCALHOST, port=DPF_DEFAULT_PORT, timeout=10):
         process, port, timeout, lines, current_errors, stderr=None, stdout=None)
 
 
-def launch_dpf_on_docker(docker_config, ansys_path=None, ip=LOCALHOST, port=DPF_DEFAULT_PORT,
-                         timeout=10):
+def launch_dpf_on_docker(running_docker_config=server_factory.RunningDockerConfig(),
+                         ansys_path=None,
+                         ip=LOCALHOST,
+                         port=DPF_DEFAULT_PORT,
+                         timeout=10.):
     """Launch Ansys DPF.
 
     Parameters
     ----------
+    running_docker_config : server_factory.RunningDockerConfig, optional
+        To start DPF server as a docker, specify the docker configurations here.
     ansys_path : str, optional
         Root path for the Ansys installation directory. For example, ``"/ansys_inc/v212/"``.
         The default is the latest Ansys installation.
@@ -219,32 +227,39 @@ def launch_dpf_on_docker(docker_config, ansys_path=None, ip=LOCALHOST, port=DPF_
         Maximum number of seconds for the initialization attempt.
         The default is ``10``. Once the specified number of seconds
         passes, the connection fails.
-    docker_config : server_factory.DockerConfig, optional
-        To start DPF server as a docker, specify the docker configurations here.
-
-    Returns
-    -------
-    running_docker_config : server_factory.RunningDockerConfig
 
     """
-    process = _run_launch_server_process(ip, port, ansys_path, docker_config)
+    process = _run_launch_server_process(ip, port, ansys_path, running_docker_config)
 
     # check to see if the service started
+    cmd_lines = []
+    # Creating lock for threads
+    lock = Lock()
+    lock.acquire()
     lines = []
-    docker_id = []
     current_errors = []
-    running_docker_config = server_factory.RunningDockerConfig(docker_server_port=port)
+    running_docker_config.docker_server_port = port
 
     def read_stdout():
-        for line in io.TextIOWrapper(process.stdout, encoding="utf-8"):
-            LOG.debug(line)
-            lines.append(line)
-            running_docker_config.init_with_stdout(docker_config, LOG, lines, timeout)
+        with io.TextIOWrapper(process.stdout, encoding="utf-8") as log_out:
+            for line in log_out:
+                LOG.debug(line)
+                cmd_lines.append(line)
+                lock.release()
+            running_docker_config.listen_to_process(LOG, cmd_lines, lines, timeout)
+
+    def read_stderr():
+        with io.TextIOWrapper(process.stderr, encoding="utf-8") as log_err:
+            for line in log_err:
+                LOG.error(line)
+                current_errors.append(line)
+            while lock.locked():
+                pass
+            running_docker_config.listen_to_process(LOG, cmd_lines, current_errors,
+                                                    timeout, False)
 
     _wait_and_check_server_connection(
-        process, port, timeout, lines, current_errors, stderr=None, stdout=read_stdout)
-
-    return running_docker_config
+        process, port, timeout, lines, current_errors, stderr=read_stderr, stdout=read_stdout)
 
 
 def launch_remote_dpf(version=None):
@@ -341,6 +356,7 @@ class BaseServer(abc.ABC):
         self._server_id = None
         self._session_instance = None
         self._base_service_instance = None
+        self._context = None
         self._docker_config = server_factory.RunningDockerConfig()
 
     def set_as_global(self, as_global=True):
@@ -444,6 +460,43 @@ class BaseServer(abc.ABC):
     def shutdown(self):
         pass
 
+    def release(self):
+        """Clears the available Operators and Releases licenses when necessary.
+
+        Notes
+        -----
+        Available with server's version starting at 6.0 (Ansys 2023R2).
+        """
+        self._base_service.release_dpf()
+
+    def apply_context(self, context):
+        """Defines the settings that will be used to load DPF's plugins.
+        A DPF xml file can be used to list the plugins and set up variables.
+
+        Parameters
+        ----------
+        context : ServerContext
+            The context allows to choose which capabilities are available server side.
+
+        Notes
+        -----
+        Available with server's version starting at 6.0 (Ansys 2023R2).
+        """
+        self._base_service.apply_context(context)
+        self._context = context
+
+    @property
+    def context(self):
+        """Returns the settings used to load DPF's plugins.
+        To update the context server side, use
+        :func:`ansys.dpf.core.BaseServer.server_types.apply_context`
+
+        Returns
+        -------
+        ServerContext
+        """
+        return self._context
+
     def check_version(self, required_version, msg=None):
         """Check if the server version matches with a required version.
 
@@ -575,6 +628,7 @@ class GrpcServer(CServer):
                  docker_config=RUNNING_DOCKER,
                  use_pypim=True,
                  num_connection_tryouts=3,
+                 context=server_context.SERVER_CONTEXT
                  ):
         # Load DPFClientAPI
         from ansys.dpf.core.misc import is_pypim_configured
@@ -596,8 +650,9 @@ class GrpcServer(CServer):
                 port = int(address.split(":")[-1])
 
             elif docker_config.use_docker:
-                self.docker_config = launch_dpf_on_docker(
-                    docker_config=docker_config,
+                self.docker_config = server_factory.RunningDockerConfig(docker_config)
+                launch_dpf_on_docker(
+                    running_docker_config=self.docker_config,
                     ansys_path=ansys_path, ip=ip, port=port, timeout=timeout)
             else:
                 launch_dpf(ansys_path, ip, port, timeout=timeout)
@@ -612,6 +667,11 @@ class GrpcServer(CServer):
         self.live = True
         self._create_shutdown_funcs()
         self._check_first_call(num_connection_tryouts)
+        try:
+            self._base_service.initialize_with_context(context)
+            self._context = context
+        except errors.DpfVersionNotSupported:
+            pass
         self.set_as_global(as_global=as_global)
 
     def _check_first_call(self, num_connection_tryouts):
@@ -650,11 +710,13 @@ class GrpcServer(CServer):
         if self._remote_instance:
             self._remote_instance.delete()
         try:
-            self._preparing_shutdown_func[0](self._preparing_shutdown_func[1])
+            if hasattr(self, "_preparing_shutdown_func"):
+                self._preparing_shutdown_func[0](self._preparing_shutdown_func[1])
         except Exception as e:
             warnings.warn("couldn't prepare shutdown: " + str(e.args))
         try:
-            self._shutdown_func[0](self._shutdown_func[1])
+            if hasattr(self, "_shutdown_func"):
+                self._shutdown_func[0](self._shutdown_func[1])
         except Exception as e:
             warnings.warn("couldn't shutdown server: " + str(e.args))
         self._docker_config.remove_docker_image()
@@ -691,7 +753,7 @@ class GrpcServer(CServer):
         try:
             return self.info["server_ip"]
         except:
-            return 0
+            return ""
 
     @property
     def port(self):
@@ -709,11 +771,11 @@ class GrpcServer(CServer):
     @property
     def external_ip(self):
         """Public IP address of the server.
-        Is the same as  :func:`ansys.dpf.core.LegacyGrpcServer.ip` in all cases except
+        Is the same as  :func:`ansys.dpf.core.GrpcServer.ip` in all cases except
         for servers using a gateway:
         for example, servers running in Docker Images might have an internal
-        :func:`ansys.dpf.core.LegacyGrpcServer.ip` different from the public
-        :func:`ansys.dpf.core.LegacyGrpcServer.external_ip`, the latter should be used to get
+        :func:`ansys.dpf.core.GrpcServer.ip` different from the public
+        :func:`ansys.dpf.core.GrpcServer.external_ip`, the latter should be used to get
         connected to the server from outside the Docker Image.
 
         Returns
@@ -725,11 +787,11 @@ class GrpcServer(CServer):
     @property
     def external_port(self):
         """Public Port of the server.
-        Is the same as  :func:`ansys.dpf.core.LegacyGrpcServer.port` in all cases except
+        Is the same as  :func:`ansys.dpf.core.GrpcServer.port` in all cases except
         for servers using a gateway:
         for example, servers running in Docker Images might have an internal
-        :func:`ansys.dpf.core.LegacyGrpcServer.port` different from the public
-        :func:`ansys.dpf.core.LegacyGrpcServer.external_port`, the latter should be used to get
+        :func:`ansys.dpf.core.GrpcServer.port` different from the public
+        :func:`ansys.dpf.core.GrpcServer.external_port`, the latter should be used to get
         connected to the server from outside the Docker Image.
 
         Returns
@@ -758,12 +820,13 @@ class InProcessServer(CServer):
                  ansys_path=None,
                  as_global=True,
                  load_operators=True,
-                 timeout=None):
+                 timeout=None,
+                 context=server_context.SERVER_CONTEXT
+                 ):
         # Load DPFClientAPI
         super().__init__(ansys_path=ansys_path, load_operators=load_operators)
         # Load DataProcessingCore
         from ansys.dpf.gate.utils import data_processing_core_load_api
-        from ansys.dpf.gate import data_processing_capi
         name = "DataProcessingCore"
         path = _get_dll_path(name, ansys_path)
         try:
@@ -774,7 +837,14 @@ class InProcessServer(CServer):
                     f"DPF directory not found at {os.path.dirname(path)}"
                     f"Unable to locate the following file: {path}")
             raise e
-        data_processing_capi.DataProcessingCAPI.data_processing_initialize_with_context(1, None)
+        try:
+            self.apply_context(context)
+        except errors.DpfVersionNotSupported:
+            self._base_service.initialize_with_context(
+                server_context.AvailableServerContexts.premium
+            )
+            self._context = server_context.AvailableServerContexts.premium
+            pass
         self.set_as_global(as_global=as_global)
 
     @property
@@ -856,12 +926,13 @@ class LegacyGrpcServer(BaseServer):
             ansys_path=None,
             ip=LOCALHOST,
             port=DPF_DEFAULT_PORT,
-            timeout=10,
+            timeout=5,
             as_global=True,
             load_operators=True,
             launch_server=True,
             docker_config=RUNNING_DOCKER,
             use_pypim=True,
+            context=server_context.SERVER_CONTEXT
     ):
         """Start the DPF server."""
         # Use ansys.grpc.dpf
@@ -894,9 +965,11 @@ class LegacyGrpcServer(BaseServer):
             else:
 
                 if docker_config.use_docker:
-                    self.docker_config = launch_dpf_on_docker(docker_config=docker_config,
-                                                              ansys_path=ansys_path, ip=ip,
-                                                              port=port, timeout=timeout)
+                    self.docker_config = server_factory.RunningDockerConfig(docker_config)
+                    launch_dpf_on_docker(
+                        running_docker_config=self.docker_config,
+                        ansys_path=ansys_path, ip=ip,
+                        port=port, timeout=timeout)
                 else:
                     launch_dpf(ansys_path, ip, port, timeout=timeout)
                     self._local_server = True
@@ -914,6 +987,11 @@ class LegacyGrpcServer(BaseServer):
         self._create_shutdown_funcs()
 
         check_ansys_grpc_dpf_version(self, timeout)
+        try:
+            self._base_service.initialize_with_context(context)
+            self._context = context
+        except errors.DpfVersionNotSupported:
+            pass
         self.set_as_global(as_global=as_global)
 
     def _create_shutdown_funcs(self):
@@ -1038,7 +1116,8 @@ class LegacyGrpcServer(BaseServer):
     def shutdown(self):
         if self._own_process and self.live:
             try:
-                self._preparing_shutdown_func[0](self._preparing_shutdown_func[1])
+                if hasattr(self, "_preparing_shutdown_func"):
+                    self._preparing_shutdown_func[0](self._preparing_shutdown_func[1])
             except Exception as e:
                 warnings.warn("couldn't prepare shutdown: " + str(e.args))
 
@@ -1046,7 +1125,8 @@ class LegacyGrpcServer(BaseServer):
                 self._remote_instance.delete()
             else:
                 try:
-                    self._shutdown_func[0](self._shutdown_func[1])
+                    if hasattr(self, "_shutdown_func"):
+                        self._shutdown_func[0](self._shutdown_func[1])
                 except Exception as e:
                     try:
                         if self.meet_version("4.0"):
